@@ -7,10 +7,13 @@ import pkg_resources
 #ageModel = "kraken_image_processing/models/age_net.caffemodel"
 
 
-ageProto = pkg_resources.resource_stream(__name__, 'models/age_deploy.prototxt')
+#ageProto = pkg_resources.resource_stream(__name__, 'models/age_deploy.prototxt')
 
-ageModel = pkg_resources.resource_stream(__name__, 'models/age_net.caffemodel')
+#ageModel = pkg_resources.resource_stream(__name__, 'models/age_net.caffemodel')
 
+ageProto =  'models/age_deploy.prototxt'
+
+ageModel = 'models/age_net.caffemodel'
 
 
 MODEL_MEAN_VALUES = (78.4263377603, 87.7689143744, 114.895847746)
