@@ -5,13 +5,13 @@ import pkg_resources
 
 
 
-#genderProto = "kraken_image_processing/models/gender_deploy.prototxt"
-#genderModel = "kraken_image_processing/models/gender_net.caffemodel"
+genderProto = "models/gender_deploy.prototxt"
+genderModel = "models/gender_net.caffemodel"
 
 
-genderProto = pkg_resources.resource_stream(__name__, 'models/gender_deploy.prototxt')
+#genderProto = pkg_resources.resource_stream(__name__, 'models/gender_deploy.prototxt')
 
-genderModel = pkg_resources.resource_stream(__name__, 'models/gender_net.caffemodel')
+#genderModel = pkg_resources.resource_stream(__name__, 'models/gender_net.caffemodel')
 
 
 
